@@ -511,8 +511,10 @@ class Termino(object):
     @property
     def periodos(self):
         data = []
+        periodes_no_facturables = []
         if hasattr(self.termino, 'Periodo'):
             period_number = 1
+            max_facturat = period_number
 
             for d in self.termino.Periodo:
                 period_name = 'P{0}'.format(period_number)
@@ -521,7 +523,22 @@ class Termino(object):
                 )
                 if period.es_facturable():
                     data.append(period)
-                    period_number += 1
+                    max_facturat = period_number
+                else:
+                    periodes_no_facturables.append((d, period_number))
+                period_number += 1
+
+            if periodes_no_facturables:
+                max_no_facturat = max([x[1] for x in periodes_no_facturables])
+                # Per les 6.1 ens envien periodes amb preu i quantitat 0 pero si que els hem de gestionar
+                if max_facturat > max_no_facturat:
+                    for d, period_number in periodes_no_facturables:
+                        period_name = 'P{0}'.format(period_number)
+                        period = self.PERIODO_TYPE(
+                            d, period_name, self.fecha_desde, self.fecha_hasta
+                        )
+                        data.append(period)
+
         return data
 
     @property
